==> connectonion-0.1.3.tar.gz: connectonion-0.1.3/connectonion/cli/templates/web-research/agent.py <==
#!/usr/bin/env python3
"""Web research agent with data extraction capabilities."""

import os
import json
import requests
from typing import Dict, List, Any
from connectonion import Agent, llm_do


def search_web(query: str) -> str:
    """Search the web for information.
    
    Args:
        query: Search query
        
    Returns:
        Search results summary
    """
    # This is a placeholder - you would integrate with a real search API
    return f"Searching for: {query}\n\nResults:\n1. Example result about {query}\n2. Another relevant finding"


def extract_data(url: str, data_type: str = "text") -> Dict[str, Any]:
    """Extract data from a webpage.
    
    Args:
        url: URL to extract data from
        data_type: Type of data to extract (text, links, images)
        
    Returns:
        Extracted data dictionary
    """
    try:
        response = requests.get(url, timeout=10)
        response.raise_for_status()
        
        # Simple extraction logic - expand as needed
        if data_type == "text":
            # In production, use BeautifulSoup or similar
            return {
                "url": url,
                "status": response.status_code,
                "content_length": len(response.text),
                "preview": response.text[:500]
            }
        else:
            return {"url": url, "data_type": data_type, "note": "Extraction not implemented"}
            
    except Exception as e:
        return {"error": str(e), "url": url}


def analyze_data(data: str, analysis_type: str = "summary") -> str:
    """Analyze extracted data.
    
    Args:
        data: Data to analyze
        analysis_type: Type of analysis (summary, sentiment, keywords)
        
    Returns:
        Analysis results
    """
    # Use LLM for analysis
    prompt = f"Perform {analysis_type} analysis on this data: {data[:1000]}"
    return llm_do(prompt)


def save_research(topic: str, findings: List[str], filename: str = None) -> str:
    """Save research findings to a file.
    
    Args:
        topic: Research topic
        findings: List of findings
        filename: Output filename (optional)
        
    Returns:
        Confirmation message
    """
    if not filename:
        filename = f"research_{topic.replace(' ', '_')}.json"
    
    research_data = {
        "topic": topic,
        "findings": findings,
        "timestamp": __import__('datetime').datetime.now().isoformat()
    }
    
    with open(filename, 'w') as f:
        json.dump(research_data, f, indent=2)
    
    return f"Research saved to {filename}"


def main():
    """Run the web research agent."""
    # Create agent with web research tools
    agent = Agent(
        name="web-research-agent",
        tools=[search_web, extract_data, analyze_data, save_research],
        model=os.getenv("MODEL", "o4-mini")
    )
    
    # Example research task
    response = agent.run(
        "Research the latest trends in AI and summarize the key findings"
    )
    print(response)


if __name__ == "__main__":
    main()

==> connectonion-0.3.3.tar.gz: connectonion-0.3.3/connectonion/cli/templates/web-research/agent.py <==
#!/usr/bin/env python3
"""Web research agent with data extraction capabilities."""

import os
import json
import requests
from typing import Dict, List, Any
from dotenv import load_dotenv
from connectonion import Agent, llm_do

# Load environment variables from .env file
load_dotenv()


def search_web(query: str) -> str:
    """Search the web for information.
    
    Args:
        query: Search query
        
    Returns:
        Search results summary
    """
    # This is a placeholder - you would integrate with a real search API
    return f"Searching for: {query}\n\nResults:\n1. Example result about {query}\n2. Another relevant finding"


def extract_data(url: str, data_type: str = "text") -> Dict[str, Any]:
    """Extract data from a webpage.
    
    Args:
        url: URL to extract data from
        data_type: Type of data to extract (text, links, images)
        
    Returns:
        Extracted data dictionary
    """
    try:
        response = requests.get(url, timeout=10)
        response.raise_for_status()
        
        # Simple extraction logic - expand as needed
        if data_type == "text":
            # In production, use BeautifulSoup or similar
            return {
                "url": url,
                "status": response.status_code,
                "content_length": len(response.text),
                "preview": response.text[:500]
            }
        else:
            return {"url": url, "data_type": data_type, "note": "Extraction not implemented"}
            
    except Exception as e:
        return {"error": str(e), "url": url}


def analyze_data(data: str, analysis_type: str = "summary") -> str:
    """Analyze extracted data.
    
    Args:
        data: Data to analyze
        analysis_type: Type of analysis (summary, sentiment, keywords)
        
    Returns:
        Analysis results
    """
    # Use LLM for analysis
    prompt = f"Perform {analysis_type} analysis on this data: {data[:1000]}"
    return llm_do(prompt)


def save_research(topic: str, findings: List[str], filename: str = None) -> str:
    """Save research findings to a file.
    
    Args:
        topic: Research topic
        findings: List of findings
        filename: Output filename (optional)
        
    Returns:
        Confirmation message
    """
    if not filename:
        filename = f"research_{topic.replace(' ', '_')}.json"
    
    research_data = {
        "topic": topic,
        "findings": findings,
        "timestamp": __import__('datetime').datetime.now().isoformat()
    }
    
    with open(filename, 'w') as f:
        json.dump(research_data, f, indent=2)
    
    return f"Research saved to {filename}"


def main():
    """Run the web research agent."""
    # Create agent with web research tools
    agent = Agent(
        name="web-research-agent",
        tools=[search_web, extract_data, analyze_data, save_research],
        model=os.getenv("MODEL", "co/o4-mini")
    )
    
    # Example research task
    response = agent.input(
        "Research the latest trends in AI and summarize the key findings"
    )
    print(response)


if __name__ == "__main__":
    main()
